@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20260209.1625
-;; Package-Revision: 444be6919070
+;; Package-Version: 20260210.1242
+;; Package-Revision: 22d2d8a92b8d
 ;; URL: https://github.com/jamescherti/vim-tab-bar.el
 ;; Keywords: frames
 ;; Package-Requires: ((emacs "28.1"))
@@ -335,10 +335,9 @@ ungrouped tabs."
                         :strike-through 'unspecified
                         :stipple 'unspecified)
 
-    ;; Fix: entered--Lisp error: (error "Invalid face box" :line-width 3 :color
-    ;; unspecified :style nil)
-    (when (or (not (daemonp))
-              (and frame (display-graphic-p frame)))
+    ;; The condition (display-graphic-p frame) fixes: entered--Lisp error:
+    ;; (error "Invalid face box" :line-width 3 :color unspecified :style nil)
+    (when (display-graphic-p frame)
       (set-face-attribute
        'tab-bar frame
        :box `(:line-width 3 :color ,bg-tab-inactive :style nil))
